<?php

declare(strict_types = 1);

namespace Drupal\form_decorator_example\FormDecorator;

use Drupal\Core\Form\FormStateInterface;
use Drupal\form_decorator\FormDecoratorBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * @FormDecorator(hook = "form_user_login_form_alter")
 */
final class DependencyInjection extends FormDecoratorBase implements ContainerFactoryPluginInterface {
  use StringTranslationTrait;

  /**
   *
   */
  public static function create(ContainerInterface $container, $configuration, $plugin_id, $plugin_definition) {
    return new self($configuration, $plugin_id, $plugin_definition,
      $container->get('entity_type.manager')
    );
  }

  /**
   *
   */
  public function __construct(array $configuration,
  $plugin_id,
  $plugin_definition,
    protected EntityTypeManagerInterface $entityTypeManager
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
  }

  /**
   *
   */
  public function buildForm(array $form, FormStateInterface $form_state, ...$args) {
    $form = $this->inner->buildForm($form, $form_state, ...$args);
    $anonymous = $this->entityTypeManager->getStorage('user')->load(0);
    $form['info'] = [
      '#markup' => $this->t('If you are not logged in you work as @name.', ['@name' => $anonymous->getDisplayName()]),
    ];
    return $form;
  }

}
